@@ -1,6 +1,4 @@
-use std::fmt::Display;
-use std::fmt::Formatter;
-use std::fmt::Result;
+use std::fmt;
 
 use crate::_Object;
 
@@ -9,6 +7,9 @@ use crate::_Object;
 #[derive(Copy)]
 #[derive(Clone)]
 #[derive(Default)]
+#[derive(PartialEq)]
+#[derive(Hash)]
+#[derive(Eq)]
 pub struct Bool {
     _bool: bool,
 }
@@ -25,6 +26,30 @@ impl Bool {
     }
 }
 
+
+impl From<bool> for Bool {
+    fn from(_bool: bool) -> Self {
+        Bool {
+            _bool,
+        }
+    }
+}
+
+
+impl From<i32> for Bool {
+    fn from(_int: i32) -> Self {
+        if _int > 0 {
+            return Bool {
+                _bool: true
+            };
+        }
+        Bool {
+            _bool: false
+        }
+    }
+}
+
+
 impl _Object for Bool {
     fn __str__(&self) -> String {
         if self._bool {
@@ -34,17 +59,28 @@ impl _Object for Bool {
         }
     }
 
-    fn __len__(&self) -> usize {
-        8
-    }
-
     fn __repr__(&self) -> String {
         self.__str__()
     }
 }
 
-impl Display for Bool {
-    fn fmt(&self, formatter: &mut Formatter<'_>) -> Result {
-        write!(formatter, "{}", self.__str__())
+
+impl fmt::Display for Bool {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}", self.__str__())
+    }
+}
+
+
+impl fmt::Debug for Bool {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "Bool<{}>", self.__str__())
+    }
+}
+
+
+impl PartialEq<bool> for Bool {
+    fn eq(&self, other: &bool) -> bool {
+        self._bool == *other
     }
 }
