@@ -1,12 +1,14 @@
-use std::fmt::Display;
-use std::fmt::Formatter;
-use std::fmt::Result;
+use std::fmt;
 
 
 use crate::_Object;
 
 
-#[derive(Copy, Clone)]
+#[derive(Copy)]
+#[derive(Clone)]
+#[derive(Eq)]
+#[derive(PartialEq)]
+#[derive(Hash)]
 /// Char struct that handles rust char
 pub struct Char {
     _char: char,
@@ -31,6 +33,14 @@ impl From<char> for Char {
     }
 }
 
+impl From<u8> for Char {
+    fn from(_int: u8) -> Self {
+        Char {
+            _char: _int as char,
+        }
+    }
+}
+
 impl Default for Char {
     fn default() -> Self {
         Char {
@@ -47,14 +57,10 @@ impl _Object for Char {
     fn __repr__(&self) -> String {
         format!("'{}'", self._char)
     }
-
-    fn __len__(&self) -> usize {
-        8
-    }
 }
 
-impl Display for Char {
-    fn fmt(&self, formatter: &mut Formatter<'_>) -> Result {
+impl fmt::Display for Char {
+    fn fmt(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
         if formatter.alternate() {
             write!(formatter, "'{}'", self._char)
         } else {
@@ -62,3 +68,19 @@ impl Display for Char {
         }
     }
 }
+
+impl fmt::Debug for Char {
+    fn fmt(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
+        if formatter.alternate() {
+            write!(formatter, "Char<'{}'>", self._char)
+        } else {
+            write!(formatter, "Char<{}>", self._char)
+        }
+    }
+}
+
+impl PartialEq<char> for Char {
+    fn eq(&self, other: &char) -> bool {
+        self._char == *other
+    }
+}
