@@ -7,6 +7,7 @@ use unindent::{
     Unindent,
 };
 
+use std::hash::Hash;
 use crate::_Object;
 use crate::type_of;
 
@@ -18,41 +19,32 @@ pub struct Float<T: Sized> {
     _float: T,
 }
 
-// impl<T> Float<T>
-// where T: Sized
-// {
-//     pub fn new() -> Float<T> {
-//         Float {
-//             _float: 0.0f32
-//         }
-//     }
-// }
 
-// impl Float<f64>
-// {
-//     pub fn new() -> Float<f64> {
-//         Float {
-//             _float: 0.0f64
-//         }
-//     }
-// }
-
-impl From<f32> for Float<f32> {
-    fn from(_float: f32) -> Self {
+impl<T> Float<T>
+where
+    T: Sized,
+{
+    /// constructor
+    /// creates a Float object from any float (f32, f64)
+    pub fn new(_float: T) -> Self {
         Float {
             _float,
         }
     }
 }
 
-impl From<f64> for Float<f64> {
-    fn from(_float: f64) -> Self {
+impl<T> From<T> for Float<T>
+where
+    T: Sized,
+{
+    fn from(_float: T) -> Self {
         Float {
             _float,
         }
     }
 }
 
+
 impl Default for Float<f32> {
     fn default() -> Self {
         Float {
@@ -70,53 +62,32 @@ impl Default for Float<f64> {
 }
 
 
-impl _Object for Float<f32> {
+impl<T> _Object for Float<T>
+where
+    T: Sized + fmt::Display,
+{
     fn __repr__(&self) -> String {
         format!("{}", self._float)
     }
 
-    fn __len__(&self) -> usize {
-        self._float as usize
-    }
-
-    fn __str__(&self) -> String {
-        format!("{}", self._float)
-    }
-}
-
-impl _Object for Float<f64> {
-    fn __repr__(&self) -> String {
-        format!("{}", self._float)
-    }
-
-    fn __len__(&self) -> usize {
-        self._float as usize
-    }
-
     fn __str__(&self) -> String {
         format!("{}", self._float)
     }
 }
 
 
-impl fmt::Display for Float<f32> {
+/// T cannot be formatted with the default formatter
+/// thats why there are implementations for every float possible
+impl<T> fmt::Display for Float<T>
+where
+    T: Sized + fmt::Display,
+{
     fn fmt(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
         let _type = type_of(&self._float);
         if formatter.alternate() {
-            write!(formatter, "{} -> <{}>", self.__str__(), _type)
+            write!(formatter, "{} -> <{}>", self._float, _type)
         } else {
-            write!(formatter, "{}", self.__str__())
-        }
-    }
-}
-
-impl fmt::Display for Float<f64> {
-    fn fmt(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
-        let _type = type_of(&self._float);
-        if formatter.alternate() {
-            write!(formatter, "{} -> <{}>", self.__str__(), _type)
-        } else {
-            write!(formatter, "{}", self.__str__())
+            write!(formatter, "{}", self._float)
         }
     }
 }
@@ -151,19 +122,12 @@ where
     }
 }
 
-// impl fmt::Debug for Float<f64> {
-//     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-//         // https://doc.rust-lang.org/std/fmt/struct.Formatter.html#method.alternate
-//         let _type = "f64";
 
-//         if f.alternate() {
-//             let _fmt = format!("Float<{}> {{
-//                 _float: {}
-//             }}", _type, self._float);
-//             let _fmt = _fmt.unindent();
-//             write!(f,  "{}", _fmt)
-//         } else {
-//             write!(f, "Float<{}> {{ _float: {} }}", _type, self._float)
-//         }
-//     }
-// }
+impl<T> PartialEq<T> for Float<T>
+where
+    T: Sized + std::cmp::PartialEq,
+{
+    fn eq(&self, other: &T) -> bool {
+        self._float == *other
+    }
+}
