@@ -21,9 +21,12 @@ use std::fmt;
 
 use std::error;
 
+use std::ops::Add;
 use std::ops::Deref;
+
 use std::str::FromStr;
 
+
 use crate::_Object;
 use crate::Object;
 use crate::Int;
@@ -31,8 +34,8 @@ use crate::Float;
 use crate::_String;
 use crate::Char;
 use crate::Bool;
-use crate::print;
 use crate::type_of;
+use crate::print;
 
 
 use super::Append;
@@ -60,9 +63,40 @@ pub struct List {
 
 /// if you want to use max(&list) you need the impl for &List
 /// how comes that for Object work by default
-impl Iterable for &List {
+impl Iterable for List {
+    fn __len__(&self) -> usize {
+        self._list.len()
+    }
 }
 
+// impl Iterable for &List {
+//     fn __len__(&self) -> usize {
+//         self._list.len()
+//     }
+// }
+
+
+// TODO implement PartialEq for List
+// impl PartialEq for List {
+//     fn eq(&self, _List: &Self) -> bool {
+//         for (o1, o2) in _List._list.iter().zip() {
+//             if o1 == o2 {
+//                 true
+//             }
+//         }
+//         false
+//     }
+
+//     fn ne(&self, other: &Self) -> bool {
+//         for (o1, o2) in _List._list.iter().zip() {
+//             if o1 != o2 {
+//                 true
+//             }
+//         }
+//         false
+//     }
+// }
+
 
 /// its implementation
 impl List {
@@ -100,10 +134,6 @@ impl Default for List {
 
 
 impl _Object for List {
-    fn __len__(&self) -> usize {
-        self._list.len()
-    }
-
     // >>>  x = ['hello', '1', '2', '3', '1', '2', '3', 123, 123, ['w', 'o', 'r', 'k', 'i', 'n', 'g'], 123.123, 123.123, 123.123, 'asdasd', ['s', 'o', 'm', 'e', 't', 'h', 'i', 'n',
     // ... 'g'], 'python string', True, False, False]
     // >>> x
@@ -216,7 +246,42 @@ impl fmt::Display for List {
     }
 }
 
-///
+impl fmt::Debug for List {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        // if list is empty then we print '[]'
+        if self._list.is_empty() {
+            write!(f, "[]");
+            return Ok(());
+        }
+
+
+        let zero = self._list.get(0).unwrap();
+        // print the first element of the list
+        match zero {
+            Object::String(obj) => write!(f, "[{:?}", obj.__repr__()),
+            Object::Char(obj) => write!(f, "[{:?}", obj.__repr__()),
+            _ => write!(f, "[{:?}", zero),
+        };
+
+        // print the other elements of the list but from index = 1
+        for _object in self._list.iter().skip(1) {
+            match _object {
+                Object::String(obj) => {
+                    write!(f, ", {}", obj.__repr__())
+                },
+                Object::Char(obj) => {
+                    write!(f, ", {}", obj.__repr__())
+                },
+                _ => write!(f, ", {}", _object),
+            };
+
+            // ostream.push_str(&_object.fmt(f).unwrap());
+        }
+        write!(f, "]")
+    }
+}
+
+
 impl Deref for List {
     type Target = VecDeque<Object>;
 
@@ -274,7 +339,8 @@ impl From<i32> for List {
     #[doc = include_str!("../../docs/python_list/showcase.md")]
     fn from(_integer: i32) -> List {
         let mut vector_deque = VecDeque::new();
-        vector_deque.push_back(Object::Int(Int::new(_integer)));
+        vector_deque
+            .push_back(Object::Int32(Int::<i32>::new(_integer)));
         List {
             _list: vector_deque,
         }
@@ -329,3 +395,21 @@ impl FromIterator<String> for List {
         string_list
     }
 }
+
+
+/// list concatenation
+impl Add for List {
+    type Output = List;
+
+    /// list1 + list2 == list3
+    fn add(self, rhs: Self) -> Self::Output {
+        let mut new_list = List::new();
+        for _object in self._list {
+            new_list.append_back(_object);
+        }
+        for _object in rhs._list {
+            new_list.append_back(_object);
+        }
+        new_list
+    }
+}
