@@ -1,7 +1,9 @@
 mod list;
 mod append;
 mod append_front;
+mod extend;
 
 pub use list::List;
 pub use append::Append;
 pub use append_front::AppendFront;
+pub use extend::Extend;
